@@ -67,7 +67,7 @@
 #if LIBAVCODEC_VERSION_INT < AV_VERSION_INT(56, 56, 0)
 #define AUBIO_AVCODEC_MAX_BUFFER_SIZE FF_MIN_BUFFER_SIZE
 #else
-#define AUBIO_AVCODEC_MAX_BUFFER_SIZE AV_INPUT_BUFFER_MIN_SIZE
+#define AUBIO_AVCODEC_MAX_BUFFER_SIZE 16384
 #endif
 
 #if LIBAVCODEC_VERSION_MAJOR >= 59
